package main

import (
	"log"
	"os"

	"git.pbiernat.dev/egommerce/catalog-service/internal"

	svr "git.pbiernat.dev/egommerce/catalog-service/internal/server"
	baseCnf "git.pbiernat.dev/egommerce/go-api-pkg/config"
)

func main() {
	if baseCnf.ErrLoadingEnvs != nil {
		log.Panicln("Error loading .env file", baseCnf.ErrLoadingEnvs)
	}

	c := internal.NewConfig("catalog")
	app := svr.New(
		c,
		svr.WithCache(c.CacheAddr, c.CachePassword),
		svr.WithDatabase(c.DbURL),
		svr.WithEventbus(),
		svr.WithLogger(),
		svr.WithRegistry(),
	)

	while := make(chan struct{})
	err := app.Base.Start(while)
	<-while

	if err != nil {
		log.Fatalf("Failed to start server. Reason: %v\n", err)
		os.Exit(1)
	}

	os.Exit(0)
}
